<?php

defined( 'WPINC' ) or die;

if ( ! class_exists( 'Tribe__Events__Attendee_Table' ) ) {
	return;
}

/**
 * Stub Class Tribe__Events__Attendee_Table
 */
class Tribe__Events__Attendee_Table {

	/**
	 * Generates an HTML table containing attendees
	 *
	 * @param array $attendees Array of attendees such as one generated by tribe_get_attendees_by_transaction().
	 *
	 * @return string HTML attendee table
	 */
	public static function generate_attendee_table( $attendees ) {

		$header = array(
			tribe_get_event_label_singular(),
			esc_html__( 'Ticket', 'tribe-snippet' ),
			esc_html__( 'Holder Name', 'tribe-snippet' ),
			esc_html__( 'Holder Email', 'tribe-snippet' ),
			esc_html__( 'Security Code', 'tribe-snippet' ),
			esc_html__( 'Public Attendee List', 'tribe-snippet' ),
		);

		$output = '<table>';
		$output .= '<tr>';

		foreach ( $header as $th ) {
			$output .= '<th>' . $th . '</th>';
		}

		$output .= '</tr>';

		foreach ( $attendees as $attendee ) {

			$output .= '<tr>';

			$event_url  = Tribe__Events__Main::instance()->getLink( 'single', $attendee['event_id'] );
			$event_name = get_the_title( $attendee['event_id'] );
			$row_data   = array(
				'<a href="' . esc_url( $event_url ) . '">' . $event_name . '</a>',
				$attendee['ticket_name'],
				$attendee['holder_name'],
				$attendee['holder_email'],
				$attendee['security_code'],
				$attendee['optout'] ? 'Do not show me' : 'Show Me',
			);

			foreach ( $row_data as $td ) {
				$output .= '<td>' . $td . '</td>';
			}

			$output .= '</tr>';
		}

		$output .= '</table>';

		return $output;
	}
}
